'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.formProviderEffects = formProviderEffects;

var _provider = require('./provider.actions');

var _provider2 = require('./provider.utils');

function forwardSubmitFormEvent(form, values, formCtrl, formRef) {
    var payload = { values: values, formRef: formRef, formCtrl: (0, _provider2.copyFormCtrl)(formCtrl) };
    (0, _provider2.dispatchEvent)(_provider.REACT_FORMCTRL.EVENTS.FORM_SUBMITED + '#' + form, payload);
}

function forwardResetFormEvent(form, formRef) {
    var payload = { formRef: formRef };
    (0, _provider2.dispatchEvent)(_provider.REACT_FORMCTRL.EVENTS.FORM_RESETED + '#' + form, payload);
}

function forwardFieldChangedEvent(form, field, fieldCtrl, eventType) {
    var payload = { form: form, field: field, fieldCtrl: (0, _provider2.copyFieldCtrl)(fieldCtrl), eventType: eventType };
    (0, _provider2.dispatchEvent)(_provider.REACT_FORMCTRL.EVENTS.FIELD_CHANGED + '#' + form + '#' + field, payload);
}

function forwardFormChangedEvent(form, formCtrl) {
    var payload = { form: form, formCtrl: (0, _provider2.copyFormCtrl)(formCtrl) };
    (0, _provider2.dispatchEvent)(_provider.REACT_FORMCTRL.EVENTS.FORM_CHANGED + '#' + form, payload);
}

function formProviderEffects(state, action) {
    var type = action.type;
    var payload = action.payload;
    var EVENTS = _provider.REACT_FORMCTRL.EVENTS;
    var formName = payload.form;
    var fieldName = payload.field;
    var eventType = payload.eventType;
    var formCtrl = state.forms[formName];
    var fieldCtrl = fieldName && formCtrl ? formCtrl.fields[fieldName] : null;
    switch (type) {
        case EVENTS.FIELD_BLURRED:
        case EVENTS.FIELD_CHANGED:
            forwardFieldChangedEvent(formName, fieldName, fieldCtrl, eventType);
            forwardFormChangedEvent(formName, formCtrl);
            break;
        case EVENTS.REGISTER_FIELD:
            forwardFieldChangedEvent(formName, fieldName, fieldCtrl, 'registerField');
            forwardFormChangedEvent(formName, formCtrl);
            break;
        case EVENTS.FIELD_PROPS_CHANGED:
            forwardFieldChangedEvent(formName, fieldName, fieldCtrl, 'propsChanged');
            forwardFormChangedEvent(formName, formCtrl);
            break;
        case EVENTS.FORM_SUBMITED:
            forwardSubmitFormEvent(formName, formCtrl.values, formCtrl, payload.formRef);
            break;
        case EVENTS.FORM_RESETED:
            Object.keys(formCtrl.fields).forEach(function (_fieldName) {
                var _field = formCtrl.fields[_fieldName];
                forwardFieldChangedEvent(formName, _fieldName, _field, eventType);
            });
            forwardResetFormEvent(formName, payload.formRef);
            forwardFormChangedEvent(formName, formCtrl);
            break;
        case EVENTS.REGISTER_FORM:
        case EVENTS.UNREGISTER_FORM:
        case EVENTS.UNREGISTER_FIELD:
        default:
            break;
    }
}